import * as React from 'react';
import {Box, Container, Grid, Link, Button } from '@material-ui/core';
import TextField from '@mui/material/TextField';
import Autocomplete from '@mui/material/Autocomplete';
import CircularProgress from '@mui/material/CircularProgress';
import { createFilterOptions } from '@material-ui/lab/Autocomplete';
import { makeStyles } from "@material-ui/core/styles";


const useStyles = makeStyles({
    paper: {
      fontSize: '12px !important',    
    }
  });

function sleep(delay = 0) {
  return new Promise((resolve) => {
    setTimeout(resolve, delay);
  });
}

///const optionsABC = [{"id":1,"title":"CUET"},{"id":2,"title":"Engineering"},{"id":3,"title":"Medical"},{"id":4,"title":"Management"}];

export default function Asynchronous(props) {
  const classes = useStyles();
  const [open, setOpen] = React.useState(false);
  const [options, setOptions] = React.useState([]);
  const [details, setDetails] = React.useState("");
  const loading = open && options.length === 0;

  React.useEffect(() => {
    let active = true;

    if (!loading) {
      return undefined;
    }

    (async () => {
      await sleep(1e3); 
      if (active) {
            let tabsArr = [];
            if(props.tabs){
              for(let i=0; i<props.tabs.length; i++){
                tabsArr.push({"id":(i+1),"title":props.tabs[i].heading,"details":props.tabs[i].details})
              }
            }
            setOptions(tabsArr);
      }
    })();

    return () => {
      active = false;
    };
  }, [props.templateId,loading]);

  React.useEffect(() => { 
    if (!open) {
      setOptions([]);
    }
  }, [open]);

  React.useEffect(() => { 
    setDetails(props.tabs[0].details);
  }, []);

  function selectedValue(obj){
    if(obj){
      setDetails(obj.details);
    }    
  }

  

  const filterOptions = createFilterOptions({
    matchFrom: 'start',
    stringify: option => option.title,
  });

  return (
    <>    
      <Box mt={2} alignItems="center" justifyContent="center" >
				<Grid container >
          <Autocomplete
            defaultValue={{"id":1,"title":props.tabs[0].heading,"details":props.tabs[0].details}}
            //searchText = {{"id":1,"title":"CUET"}}
            //autoSelect={true}
            id="search-input-topicbox"
            freeSolo={false}
            classes={{ paper: classes.paper }}
            sx={{ width: 260, backgroundColor: '#FFF' }}
            open={open}
            onOpen={() => {
              setOpen(true);
            }}
            onClose={() => {
              setOpen(false);
            }}
            isOptionEqualToValue={(option, value) => option.title === value.title}
            getOptionLabel={(option) => option.title}
            options={options}
            loading={loading}
            filterOptions={filterOptions}
            onChange={(event, myObj) => selectedValue(myObj)}          
            renderInput={(params) => (
              <TextField 
                {...params}
                ///label={props.label} 
                //label="Select Category"
                InputProps={{
                  ...params.InputProps,
                  endAdornment: (
                    <React.Fragment>
                      {loading ? <CircularProgress color="inherit" size={20} /> : null}
                      {params.InputProps.endAdornment}
                    </React.Fragment>
                  ),
                }}
                
              />
            )}
          />
      	</Grid>
	  	</Box>
    
      <Box mt={2} alignItems="center" justifyContent="center" >  
        <Grid container >       
            {details} 
        </Grid>      
      </Box>          

    </>
  );
}

