import React, { useEffect, useRef, useState } from "react";
import Link from "next/link";
import Cookies from "js-cookie";

// Components
import LoginPop from "../components/LoginPop";
import SwipeableTopDrawer from "./SwipeableTopDrawer";
import Button from "@mui/material/Button";
import Menu from "@mui/material/Menu";
import MenuItem from "@mui/material/MenuItem";

// MUI
import AppBar from "@material-ui/core/AppBar";
import { alpha, makeStyles } from "@material-ui/core/styles";

const useStyles = makeStyles((theme) => ({
  grow: {
    flexGrow: 1,
  },
  menuButton: {
    marginRight: theme.spacing(2),
  },
  title: {
    display: "none",
    [theme.breakpoints.up("sm")]: {
      display: "block",
    },
  },
  search: {
    position: "relative",
    borderRadius: theme.shape.borderRadius,
    backgroundColor: alpha(theme.palette.common.white, 0.15),
    "&:hover": {
      backgroundColor: alpha(theme.palette.common.white, 0.25),
    },
    marginRight: theme.spacing(2),
    marginLeft: 0,
    width: "100%",
    [theme.breakpoints.up("sm")]: {
      marginLeft: theme.spacing(3),
      width: "auto",
    },
  },
  searchIcon: {
    padding: theme.spacing(0, 2),
    height: "100%",
    position: "absolute",
    pointerEvents: "none",
    display: "flex",
    alignItems: "center",
    justifyContent: "center",
  },
  inputRoot: {
    color: "inherit",
  },
  inputInput: {
    padding: theme.spacing(1, 1, 1, 0),
    // vertical padding + font size from searchIcon
    paddingLeft: `calc(1em + ${theme.spacing(4)}px)`,
    transition: theme.transitions.create("width"),
    width: "100%",
    [theme.breakpoints.up("md")]: {
      width: "20ch",
    },
  },
  sectionDesktop: {
    display: "none",
    [theme.breakpoints.up("md")]: {
      display: "flex",
    },
  },
  sectionMobile: {
    display: "flex",
    [theme.breakpoints.up("md")]: {
      display: "none",
    },
  },
}));

export default function Header(props) {
  const { course } = props;
  let [accountDetails, setAccountDetails] = useState({});
  const [anchorEl, setAnchorEl] = useState(null);
  const open = Boolean(anchorEl);
  const handleClick = (event) => {
    setAnchorEl(event.currentTarget);
  };
  const handleClose = () => {
    setAnchorEl(null);
  };

  const classes = useStyles();

  const childRefLoginPop = useRef();

  useEffect(() => {
    try {
      setAccountDetails(JSON.parse(Cookies.get("accountDetails")));
    } catch (err) {}
  }, []);

  const setHeaderCookies = () => {
    if (course) {
      Cookies.set(
        "courseDetails",
        JSON.stringify({
          subscriptionType: "Free",
          courseId: course?.courseId,
          courseName: course?.courseTitle,
          packId: "",
          promoCode: "",
        })
      );
      Cookies.set(
        "header_join_for_free",
        JSON.stringify({
          courseId: course?.courseId,
          courseName: course?.courseTitle,
        })
      );
    } else {
      Cookies.set(
        "header_join_for_free",
        JSON.stringify({
          value: "free"
        })
      );
    }
  };

  const logout = () => {
    Cookies.remove("accountDetails");
    window.location.reload();
  };

  function goLoginPop() {
    childRefLoginPop.current.handleClickOpen();
  }

  return (
    <div className={classes.grow}>
      <AppBar position="static">
        <header>
          <nav
            className="etl_header"
            style={props?.headerStyle ? props?.headerStyle : {}}
          >
            <a aria-label="header logo" href="/">
              <img
                loading="lazy"
                alt="etl logo"
                src="/logo-white.webp"
                width={160}
                height={160}
                style={{ marginLeft: "-16%" }}
              />
            </a>

            <div className="desk-none mob-menu">
              {/* <a href="/create-account" className="mybt mob">Sign Up</a> */}
              <div htmlFor="click" className="menu-btn">
                <SwipeableTopDrawer course={props?.course} />
              </div>
            </div>

            <div className="menuwarp" id="menuwarp">
              <ul
                style={{
                  display: "flex",
                  alignItems: "center",
                  flexWrap: "nowrap",
                }}
                className="menu"
                id="menu"
              >
                <li className="desk-none">
                  <SwipeableTopDrawer />
                </li>
                <li className="etl_header_link">
                  <a href="/courses/engineering">Our Courses</a>
                </li>
                <li className="etl_header_link">
                  <a href="/aboutus">About Us</a>
                </li>
                <li className="etl_header_link">
                  <a href="/contactus">Contact Us</a>
                </li>
                <li className="etl_header_link">
                  <a href="/download">Download</a>
                </li>
                {!accountDetails?.studentName ? (
                  <li
                    onClick={() => {
                      goLoginPop();
                    }}
                    className="header_login linkhver etl_header_link"
                  >
                    Login
                  </li>
                ) : (
                  <></>
                )}
                {!accountDetails?.studentName ? (
                  <li>
                    <a
                      onClick={setHeaderCookies}
                      href="/create-account"
                      className="mybt"
                    >
                      Sign up
                    </a>
                  </li>
                ) : (
                  <></>
                )}
                {accountDetails?.studentName ? (
                  <li className="header_profile">
                    <Button
                      id="basic-button"
                      className="header_profile"
                      aria-controls={open ? "basic-menu" : undefined}
                      aria-haspopup="true"
                      aria-expanded={open ? "true" : undefined}
                      onClick={handleClick}
                    >
                      <span className="header_profile_logo">
                        {accountDetails?.studentName
                          ?.substr(0, 1)
                          .toUpperCase()}
                      </span>
                      Profile
                    </Button>
                    <Menu
                      className="header_dropdown"
                      id="basic-menu"
                      anchorEl={anchorEl}
                      open={open}
                      onClose={handleClose}
                      MenuListProps={{
                        "aria-labelledby": "basic-button",
                      }}
                    >
                      <MenuItem onClick={logout}>Logout</MenuItem>
                    </Menu>
                  </li>
                ) : (
                  <></>
                )}
              </ul>
            </div>
          </nav>
        </header>
      </AppBar>

      <LoginPop ref={childRefLoginPop} />
    </div>
  );
}
