import React, { useState, useEffect } from "react";
import Paper from "@mui/material/Paper";
import IconButton from "@mui/material/IconButton";
import SearchIcon from "@mui/icons-material/Search";
import TextField from "@mui/material/TextField";
import Autocomplete from "@mui/material/Autocomplete";
import CircularProgress from "@mui/material/CircularProgress";
import { createFilterOptions } from "@material-ui/lab/Autocomplete";
import { makeStyles } from "@material-ui/core/styles";

const useStyles = makeStyles({
  paper: {
    fontSize: "12px !important",
  },
});

function sleep(delay = 0) {
  return new Promise((resolve) => {
    setTimeout(resolve, delay);
  });
}

export default function Asynchronous(props) {
  const classes = useStyles();
  const [open, setOpen] = useState(false);
  const [options, setOptions] = useState([]);
  const [courseUrl, setCourseUrl] = useState("")

  const loading = open && options.length === 0;

  useEffect(() => {
    let active = true;

    if (!loading) {
      return undefined;
    }

    (async () => {
      await sleep(1e3);
      if (active) {
        let optionArr = [];
        if (props.data) {
          props.data.map((myObjCat) =>
            myObjCat.coursesList.map((myObj) =>
              optionArr.push({
                id: myObj.courseId,
                url: myObj.courseUrl,
                title: myObj.courseTitle,
              })
            )
          );
        }
        setOptions(optionArr);
      }
    })();

    return () => {
      active = false;
    };
  }, [props.templateId, loading]);

  useEffect(() => {
    if (!open) {
      setOptions([]);
    }
  }, [open]);

  function selectedValue(obj) {
    if (obj && obj.id && obj.url) {
      window.location.href = "/course/" + obj.url;
    }
  }

  const filterOptions = createFilterOptions({
    matchFrom: "start",
    stringify: (option) => option.title,
  });

  return (
    <div className="courseSearchInput">
      <Paper
        component="form"
        sx={{ p: "2px 4px", display: "flex", alignItems: "center", width: 290 }}
      >
        <IconButton type="submit" sx={{ p: "10px" }} aria-label="search">
          <SearchIcon />
        </IconButton>
        <Autocomplete
          id="search-input-topicbox"
          freeSolo={false}
          popupIcon={""}
          classes={{ paper: classes.paper }}
          sx={{ width: 260, backgroundColor: "#FFF" }}
          open={open}
          onOpen={() => {
            setOpen(true);
          }}
          onClose={() => {
            setOpen(false);
          }}
          isOptionEqualToValue={(option, value) => option.title === value.title}
          getOptionLabel={(option) => option.title}
          options={options}
          loading={loading}
          filterOptions={filterOptions}
          onChange={(event, myObj) => selectedValue(myObj)}
          renderInput={(params) => (
              <TextField
                {...params}
                placeholder="Search course ( NEET, JEE, etc )"
                variant="standard"
                InputProps={{
                  ...params.InputProps,
                  endAdornment: (
                    <React.Fragment>
                      {loading ? (
                        <CircularProgress color="inherit" size={20} />
                      ) : null}
                      {params.InputProps.endAdornment}
                    </React.Fragment>
                  ),
                  disableUnderline: true,
                }}
              />
          )}
        />
      </Paper>
    </div>
  );
}
