import React, { useState, useRef } from "react";
import Link from "next/link";
import Cookies from "js-cookie";
import clsx from "clsx";
import { makeStyles } from "@material-ui/core/styles";
import SwipeableDrawer from "@material-ui/core/SwipeableDrawer";
import Button from "@material-ui/core/Button";
import List from "@material-ui/core/List";
import Divider from "@material-ui/core/Divider";
import ListItem from "@material-ui/core/ListItem";
import ListItemIcon from "@material-ui/core/ListItemIcon";
import ListItemText from "@material-ui/core/ListItemText";
import MenuIcon from "@material-ui/icons/Menu";
import CategoryIcon from "@material-ui/icons/Eco";
import HomeIcon from "@material-ui/icons/Home";

import LoginPop from "../components/LoginPop";

const useStyles = makeStyles({
  list: {
    width: 250,
  },
  fullList: {
    width: "auto",
  },
});

export default function SwipeableTemporaryDrawer(props) {
  const { course } = props;
  const accountDetails = Cookies.get("accountDetails");
  const classes = useStyles();
  const [state, setState] = useState({
    top: false,
    left: false,
    bottom: false,
    right: false,
  });

  const childRefLoginPop = useRef();

  function goLoginPop() {
    childRefLoginPop.current.handleClickOpen();
  }

  const setHeaderCookies = () => {
    if (course) {
      Cookies.set(
        "courseDetails",
        JSON.stringify({
          subscriptionType: "Free",
          courseId: course?.courseId,
          courseName: course?.courseTitle,
          packId: "",
          promoCode: "",
        })
      );
      Cookies.set(
        "header_join_for_free",
        JSON.stringify({
          courseId: course?.courseId,
          courseName: course?.courseTitle,
        })
      );
    } else {
      Cookies.set(
        "header_join_for_free",
        JSON.stringify({
          value: "free",
        })
      );
    }
  };

  const toggleDrawer = (anchor, open) => (event) => {
    if (
      event &&
      event.type === "keydown" &&
      (event.key === "Tab" || event.key === "Shift")
    ) {
      return;
    }

    setState({ ...state, [anchor]: open });
  };

  const list = (anchor) => (
    <div
      className={clsx(classes.list, {
        [classes.fullList]: anchor === "top" || anchor === "bottom",
      })}
      role="presentation"
      onClick={toggleDrawer(anchor, false)}
      onKeyDown={toggleDrawer(anchor, false)}
    >
      <List>
        <Link href="/">
          <ListItem button key="Home">
            <ListItemIcon>
              <HomeIcon />
            </ListItemIcon>
            <ListItemText primary="Home" />
          </ListItem>
        </Link>
      </List>
      <Divider />
      <List>
        <Link href="/courses/engineering">
          <ListItem button key="OurCourses">
            <ListItemIcon>
              <CategoryIcon />
            </ListItemIcon>
            <ListItemText primary="Our Courses" />
          </ListItem>
        </Link>
        <Link href="/aboutus">
          <ListItem button key="AboutUs">
            <ListItemIcon>
              <CategoryIcon />
            </ListItemIcon>
            <ListItemText primary="About Us" />
          </ListItem>
        </Link>
        <Link href="/contactus">
          <ListItem button key="ContactUs">
            <ListItemIcon>
              <CategoryIcon />
            </ListItemIcon>
            <ListItemText primary="Contact Us" />
          </ListItem>
        </Link>
        {!accountDetails ? (
          <>
            <a
              href="javascript:;"
              onClick={() => {
                goLoginPop();
              }}
            >
              <ListItem button key="Login">
                <ListItemIcon>
                  <CategoryIcon />
                </ListItemIcon>
                <ListItemText primary="Login" />
              </ListItem>
            </a>
            <a onClick={setHeaderCookies} href="/create-account">
              <ListItem button key="SignUp">
                <ListItemIcon>
                  <CategoryIcon />
                </ListItemIcon>
                <ListItemText primary="Join For Free" />
              </ListItem>
            </a>
          </>
        ) : (
          <></>
        )}
      </List>
    </div>
  );

  return (
    <div>
      <Button
        style={{ color: "#FFFFFF" }}
        aria-label="hamburger menu"
        onClick={toggleDrawer("right", true)}
      >
        <MenuIcon />
      </Button>
      <SwipeableDrawer
        anchor="right"
        open={state["right"]}
        onClose={toggleDrawer("right", false)}
        onOpen={toggleDrawer("right", true)}
      >
        {list("right")}
      </SwipeableDrawer>
      <LoginPop ref={childRefLoginPop} />
    </div>
  );
}
