import React from "react";
import PropTypes from "prop-types";
import { makeStyles } from "@material-ui/core/styles";
import { Box } from "@material-ui/core";

function TabPanel(props) {
  const { children, value, index, ...other } = props;

  return (
    <div
      role="tabpanel"
      hidden={value !== index}
      id={`scrollable-auto-tabpanel-${index}`}
      aria-labelledby={`scrollable-auto-tab-${index}`}
      {...other}
    >
      {value === index && (
        <Box mt={2}>
          <h4>{children}</h4>
        </Box>
      )}
    </div>
  );
}

TabPanel.propTypes = {
  children: PropTypes.node,
  index: PropTypes.any.isRequired,
  value: PropTypes.any.isRequired,
};

const useStyles = makeStyles((theme) => ({
  root: {
    flexGrow: 1,
    width: "100%",
  },
}));

export default function ScrollableTabsButtonAuto() {
  const classes = useStyles();
  const data = [
    {
      name: "Aryan Ahuja",
      review:
        "The assessments helped me figure out my weak spots and target them specifically and the best part is that it's free...Smart Learning FTW\ud83d\udcaf\ud83d\udd25",
    },
    {
      name: "Vaishnavi Singh",
      review:
        "ISTG this has been one of the best learning experiences I've had coming especially from someone who has joined and left multiple coaching centers...",
    },
    {
      name: "Mohini Gupta",
      review:
        "Honestly, I wasn't expecting to learn so much in such a short span of time. Kudos to ETL!\ud83d\ude0a",
    },
  ];

  return (
    <div
      className={classes.root}
      style={{
        display: "flex",
        flexWrap: "wrap",
        gap: "2rem",
        justifyContent: "center",
      }}
    >
      {data.map((el, index) => {
        return (
          <Box
            key={index}
            sx={{
              minWidth: "300px",
              display: "inline",
              flexDirection: "column",
              bgcolor: "white",
              p: "1.5rem",
              borderRadius: "1rem",
              maxWidth: "400px",
            }}
          >
            <div className="testimonailbox">
              <div className="topbox">
                <div className="iconn">{el.name[0]}</div>
                <div className="authorname">
                  <h5>{el.name}</h5>
                  <div className="rating">
                    <i className="star"></i>
                    <i className="star"></i>
                    <i className="star"></i>
                    <i className="star"></i>
                    <i className="star blank"></i>
                  </div>
                </div>
              </div>
              <div className="testi-cont">
                <p>{el.review}</p>
              </div>
            </div>
          </Box>
        );
      })}
    </div>
  );
}
