const withCss = require("@zeit/next-css");
const withPurgeCss = require("next-purgecss");
const OptimizeCSSAssetsPlugin = require("optimize-css-assets-webpack-plugin");
const withBundleAnalyzer = require('@next/bundle-analyzer')({
  enabled: process.env.ANALYZE === 'true'
})

const advancedHeaders = [
  {
    key: "X-DNS-Prefetch-Control",
    value: "on",
  },
  {
    key: "Strict-Transport-Security",
    value: "max-age=63072000; includeSubDomains; preload",
  },
  {
    key: "X-XSS-Protection",
    value: "1; mode=block",
  },
  {
    key: "X-Frame-Options",
    value: "SAMEORIGIN",
  },
  {
    key: "X-Content-Type-Options",
    value: "nosniff",
  },
  {
    key: "Referrer-Policy",
    value: "origin-when-cross-origin",
  },
];


// Purge Css Config
module.exports = withCss(withPurgeCss());

// Main config  
module.exports = {
  compress: true,
  future: {
    webpack5: true,
  },
  assetPrefix: './',
  async headers() {
    return [
      {
        source: "/:path*",
        headers: advancedHeaders,
      },
    ];
  },
  async redirects() {
    return [
      {
        source: '/courses',
        destination: '/courses/Engineering',
        permanent: true,
      },
    ];
  },
  webpack(config, options) {
    config.optimization.minimizer.push(new OptimizeCSSAssetsPlugin({}));
    return config;
  },
  images: {
    minimumCacheTTL: 31536000,
  },
  optimization: {
    minimize: true
  }
};

// Config for bundle analyzer
module.exports = withBundleAnalyzer({
  compress: true,
  future: {
    webpack5: true,
  },
  images: {
    minimumCacheTTL: 31536000,
  },
  env: {
      NEXT_PUBLIC_ENV: 'PRODUCTION', //your next configs goes here
  },
})