import React, {useState} from "react";
import Head from "next/head";
import axios from "axios";
import FormControlLabel from "@mui/material/FormControlLabel";
import CircularProgress from "@mui/material/CircularProgress";
import Checkbox from "@mui/material/Checkbox";
import { makeStyles } from "@material-ui/core/styles";
import { Box, Grid, TextField } from "@material-ui/core";
import Header from "../components/Header";
import Footer from "../components/Footer";
import FormHelperText from "@mui/material/FormHelperText";
import Cookies from "js-cookie";
import LoginPop from "../components/LoginPop";

import Link from "next/link";

const useStyles = makeStyles((theme) => ({
  sectionDesktop: {
    display: "none",
    [theme.breakpoints.up("md")]: {
      display: "block",
    },
  },
  sectionMobile: {
    display: "block",
    [theme.breakpoints.up("md")]: {
      display: "none",
    },
  },
}));

export default function Home(props) {
  const newaccount = Cookies.get("newaccount");
  const courseDetails = Cookies.get("courseDetails");
  let objCourse = {};
  if (courseDetails) {
    objCourse = JSON.parse(courseDetails);
  }
  const classes = useStyles();
  const [waitBtn, setWaitBtn] = useState(false);
  const [checked, setChecked] = useState(false);
  const [firstName, setFirstName] = useState("");
  const [lastName, setLastName] = useState("");
  const [mobileNumber, setMobileNumber] = useState("");

  const [firstNameVal, setFirstNameVal] = useState(false);
  const [lastNameVal, setLastNameVal] = useState(false);
  const [mobileVal, setMobileVal] = useState(false);
  const [termsVal, setTermsVal] = useState(false);
  const [mobileValMsg, setMobileValMsg] = useState(
    "Enter your mobile number"
  );

  const [firstNameValMsg, setFirstNameValMsg] = useState(
    "Enter your first name"
  );
  const [lastNameValMsg, setLastNameValMsg] = useState(
    "Enter your last name"
  );

  const [utype, setUtype] = useState("Learner");
  const childRefLoginPop = React.useRef();

  function goLoginPop() {
    childRefLoginPop.current.handleClickOpen();
  }

  React.useEffect(() => {
    const urlParams = new URLSearchParams(location.search);
    if (urlParams.has("u")) {
      setUtype(urlParams.get("u"));
    }
  }, []);

  React.useEffect(() => {
    if (newaccount) {
      const obj = JSON.parse(newaccount);
      setFirstName(obj.firstName);
      setLastName(obj.lastName);
      setMobileNumber(obj.mobile);
      setUtype(obj.utype);
      setChecked(true);
    }
  }, [newaccount]);

  function submit() {
    let letters = /^[A-Za-z\s]*$/;
    if (!firstName || firstName.trim().length < 1) {
      if (firstName) {
        setFirstName(firstName.trim());
      }
      setFirstNameVal(true);
      setFirstNameValMsg("Enter your first name");
    } else if (
      firstName &&
      firstName.trim().length > 0 &&
      !firstName.trim().match(letters)
    ) {
      setFirstNameVal(true);
      setFirstNameValMsg("It seems, first name is not valid");
    } else {
      setFirstName(firstName.trim());
      setFirstNameVal(false);
    }
    if (!lastName || lastName.trim().length < 1) {
      if (lastName) {
        setLastName(lastName.trim());
      }
      setLastNameVal(true);
      setLastNameValMsg("Enter your last name");
    } else if (
      lastName &&
      lastName.trim().length > 0 &&
      !lastName.trim().match(letters)
    ) {
      setLastNameVal(true);
      setLastNameValMsg("It seems, last name is not valid");
    } else {
      setLastName(lastName.trim());
      setLastNameVal(false);
    }
    if (!mobileNumber || mobileNumber.trim().length < 1) {
      if (mobileNumber) {
        setMobileNumber(mobileNumber.trim());
      }
      setMobileVal(true);
      return false;
    } else if (mobileNumber && mobileNumber.length < 10) {
      setMobileVal(true);
      setMobileValMsg("Mobile number is invalid");
      return false;
    } else {
      setMobileVal(false);
    }
    if (!checked) {
      setTermsVal(true);
      return false;
    } else {
      setTermsVal(false);
    }

    if (mobileNumber && firstName && lastName) {
      setWaitBtn(true);
      let axiosHeader = {
        headers: {
          "Content-Type": "multipart/mixed",
        },
      };

      const data = new FormData();
      data.append("mobile", mobileNumber);

      let apiURL = process.env.NEXT_PUBLIC_API_URL + "/checkexistsmobilenumber";
      let apiResponseTxt = "OK";
      if (utype && utype === "Teacher") {
        apiURL = process.env.NEXT_PUBLIC_API_URL + "/teacher-checkexistsmobile";
        apiResponseTxt = "success";
      } else if (utype && utype === "Parent") {
        apiResponseTxt = "success";
        apiURL = process.env.NEXT_PUBLIC_API_URL + "/parent-checkexistsmobile";
      }

      axios
        .post(apiURL, data, axiosHeader)
        .then((response) => {
          const myTimeoutWaitBtn = setTimeout(myWaitBtnStop, 6000);
          function myWaitBtnStop() {
            setWaitBtn(false);
            clearTimeout(myTimeoutWaitBtn);
          }
          ///console.log("RESPONSE RECEIVED: ", response.data.responseTxt);
          if (response.data.responseTxt === apiResponseTxt) {
            Cookies.set(
              "newaccount",
              JSON.stringify({
                firstName: firstName,
                lastName: lastName,
                mobile: mobileNumber,
                token: response.data.token,
                utype: utype,
              })
            );
            window.location.href = "verify-mobile";
            return false;
          } else if (response.data.responseTxt === "MobileExists") {
            setMobileVal(true);
            setMobileValMsg(
              "You already have an account in ETL. Please login in with User ID and Password."
            );
            if (utype && utype === "Learner") {
              window.location.href = "login?mobile=" + mobileNumber;
            }
            return false;
          } else {
            setMobileVal(true);
            setMobileValMsg("Error somewhere, Try after sometime.");
            return false;
          }
        })
        .catch((error) => {
          setMobileVal(true);
          setMobileValMsg("" + error);
          return false;
        });
    }
  }

  //   function onEnter(event){
  // 	if(event.key === 'Enter'){
  // 		submit();
  // 	}
  //   }

  function nameOnly(event) {
    if (!/[a-z ]/i.test(event.key)) {
      event.preventDefault();
      return false;
    }
  }
  function numberOnly(event) {
    if (!/[0-9]/.test(event.key)) {
      event.preventDefault();
    }
  }

  //   function goLocation(url){
  // 	window.location.href=url;
  //   }

  return (
    <>
      <Head>
        <title>Sign Up For EaseToLearn India`s Largest Learning Platform</title>
        <meta
          name="description"
          content="Online Exam Preparation For Recruitment & Entrance Exam | Online Test Series | Mock Test - EaseToLearn"
        />
        <meta
          name="keywords"
          content="Online Tests for Recruitment &amp; Entrance Exams"
        />
        <link rel="icon" href="/favicon.ico" />
      </Head>
      <main>
        <Header />

        <Box className="mainBox">
          <Box className="createAccountBox">
            <Grid container>
              <Grid
                item
                md={6}
                sm={6}
                xs={12}
                className={classes.sectionDesktop}
              >
                <img
                  loading="lazy"
                  alt="ease to learn hero banner"
                  src="/two.webp"
                />
              </Grid>
              <Grid item md={6} sm={6} xs={12}>
                <h1>CREATE AN ACCOUNT</h1>
                <h5>Let's get you signed up! </h5>
                <Grid className="frmbx">
                  <div style={{ marginBottom: 5 }}>Join EaseToLearn as a</div>

                  <Grid>
                    {utype && utype === "Learner" ? (
                      <a className="bttn mybt-dark-bb">Learner</a>
                    ) : (
                      <a
                        href="/create-account?u=Learner"
                        className="bttn mybt-dark-aa"
                      >
                        Learner
                      </a>
                    )}

                    {utype && utype === "Teacher" ? (
                      <a className="bttn mybt-dark-bb">Teacher</a>
                    ) : (
                      <a
                        href="/create-account?u=Teacher"
                        className="bttn mybt-dark-aa"
                      >
                        Teacher
                      </a>
                    )}

                    {utype && utype === "Parent" ? (
                      <a className="bttn mybt-dark-bb">Parent</a>
                    ) : (
                      <a
                        href="/create-account?u=Parent"
                        className="bttn mybt-dark-aa"
                      >
                        Parent
                      </a>
                    )}
                  </Grid>

                  <Grid container spacing={1}>
                    <Grid item md={6} sm={12} xs={12}>
                      First Name
                      <TextField
                        onChange={(event) => setFirstName(event.target.value)}
                        value={firstName}
                        onKeyPress={(event) => {
                          nameOnly(event);
                        }}
                        fullWidth
                        variant="outlined"
                      />
                      {firstNameVal ? (
                        <FormHelperText>{firstNameValMsg}</FormHelperText>
                      ) : null}
                    </Grid>
                    <Grid item md={6} sm={12} xs={12}>
                      Last Name
                      <TextField
                        onChange={(event) => setLastName(event.target.value)}
                        value={lastName}
                        onKeyPress={(event) => {
                          nameOnly(event);
                        }}
                        fullWidth
                        variant="outlined"
                      />
                      {lastNameVal ? (
                        <FormHelperText>{lastNameValMsg}</FormHelperText>
                      ) : null}
                    </Grid>
                  </Grid>
                  <Grid container spacing={1}>
                    <Grid item md={12} sm={12} xs={12}>
                      Mobile Number
                      <TextField
                        onChange={(event) =>
                          setMobileNumber(event.target.value)
                        }
                        value={mobileNumber}
                        onKeyPress={(event) => {
                          numberOnly(event);
                        }}
                        fullWidth
                        variant="outlined"
                        inputProps={{ maxLength: 10 }}
                      />
                      {mobileVal ? (
                        <FormHelperText>{mobileValMsg}</FormHelperText>
                      ) : null}
                    </Grid>
                    <Grid
                      item
                      md={12}
                      sm={12}
                      xs={12}
                      style={{ paddingLeft: 15 }}
                    >
                      <FormControlLabel
                        control={
                          <Checkbox
                            size="small"
                            checked={checked}
                            onChange={(event) => {
                              setChecked(event.target.checked);
                            }}
                          />
                        }
                        label={""}
                      />{" "}
                      <span style={{ marginLeft: -15 }}>
                        By checking this box, you agree to our
                      </span>
                      <Link href="/terms">
                        <a style={{ color: "#0000FF", marginLeft: 2 }}>
                          Terms of Use
                        </a>
                      </Link>
                      {termsVal ? (
                        <FormHelperText>
                          You must be agreed with our terms & conditions
                        </FormHelperText>
                      ) : null}
                    </Grid>
                    <Grid item md={12} sm={12} xs={12}>
                      <div className="paybtnbox">
                        {waitBtn ? (
                          <a className="paybtnwait">
                            <CircularProgress size={13} color={"inherit"} />
                            Wait...
                          </a>
                        ) : (
                          <a
                            href="javscript:;"
                            onClick={() => {
                              submit();
                            }}
                            className="paybtn"
                          >
                            Join for Free
                          </a>
                        )}
                      </div>
                    </Grid>

                    {objCourse && objCourse.subscriptionType === "Paid" ? (
                      <Grid item md={12} sm={12} xs={12}>
                        <div className="paybtnbox">
                          Already have an account?{" "}
                          <a
                            href="javascript:;"
                            onClick={() => {
                              window.location.href = "login";
                            }}
                            className="linkhver"
                            style={{ color: "#0000FF" }}
                          >
                            Login
                          </a>
                        </div>
                      </Grid>
                    ) : null}
                  </Grid>
                </Grid>
              </Grid>
            </Grid>
          </Box>
        </Box>

        <Footer />
        <LoginPop ref={childRefLoginPop} />
      </main>
    </>
  );
}

/*
export async function getServerSideProps() {
	const [specialitiesRes, healthissuesRes, articlesRes] = await Promise.all([		
	  fetch(process.env.NEXT_PUBLIC_API_URL+'/api/specialities?maxrows=6'),
	  fetch(process.env.NEXT_PUBLIC_API_URL+'/api/healthissues?maxrows=6'), 
	  fetch(process.env.NEXT_PUBLIC_API_URL+'/api/articles?maxrows=3')	  
	]);
	const [specialities, healthissues, articles] = await Promise.all([
		specialitiesRes.json(),
		healthissuesRes.json(), 
		articlesRes.json()
	]);
	return { props: { specialities, healthissues, articles } };
}
*/

//   function makeEncodeURL(str){
// 	let strArr = str.toLowerCase().split(" ");
// 	let returnURL="";
// 	for(let i=0; i<strArr.length; i++ ){
// 		returnURL+=strArr[i]+"+";
// 	}
// 	 return returnURL.trim().substring(0,returnURL.length-1);
//   }
