import React, { useState, useEffect } from "react";
import axios from "axios";
import Head from "next/head";
import Cookies from "js-cookie";

// Components
import Header from "../components/Header";
import Footer from "../components/Footer";

// Mui Components
import { makeStyles } from "@material-ui/core/styles";
import { Box, Grid, TextField } from "@material-ui/core";
import FormHelperText from "@mui/material/FormHelperText";
import CircularProgress from "@mui/material/CircularProgress";

const useStyles = makeStyles((theme) => ({
  sectionDesktop: {
    display: "none",
    [theme.breakpoints.up("md")]: {
      display: "block",
    },
  },
  sectionMobile: {
    display: "block",
    [theme.breakpoints.up("md")]: {
      display: "none",
    },
  },
}));

export default function Home(props) {
  const newaccount = Cookies.get("newaccount");
  const classes = useStyles();

  const [email, setEmail] = useState("");
  const [lastName, setLastName] = useState("");
  const [waitBtn, setWaitBtn] = useState(false);
  const [utype, setUtype] = useState("Learner");
  const [firstName, setFirstName] = useState("");
  const [newPassword, setNewPassword] = useState("");
  const [mobileNumber, setMobileNumber] = useState("");
  const [newPasswordMsg, setNewPasswordMsg] = useState("");
  const [retypeNewPassword, setRetypeNewPassword] = useState("");
  const [retypeNewPasswordMsg, setRetypeNewPasswordMsg] = useState("");

  useEffect(() => {
    if (!newaccount) {
      window.location.href = "/create-account";
    } else if (newaccount) {
      const obj = JSON.parse(newaccount);
      setFirstName(obj.firstName);
      setLastName(obj.lastName);
      setMobileNumber(obj.mobile);
      setEmail(obj.email);
      setUtype(obj.utype);
    }
  }, [newaccount]);

  function submit() {
    if (!newPassword) {
      setNewPasswordMsg("Enter your password");
      return false;
    } 
    // else if (
    //   newPassword &&
    //   !newPassword
    //     .trim()
    //     .match(/^(?=.*[0-9])(?=.*[!@#$%^&*])[a-zA-Z0-9!@#$%^&*]{8,20}$/)
    // ) {
    //   setNewPasswordMsg(
    //     "Recommended: should contain at least one number and one uppercase and lowercase letter and one special character, and at least 8 or more characters"
    //   );
    //   return false;
    // } 
    else {
      setNewPasswordMsg("");
    }
    if (!retypeNewPassword) {
      setRetypeNewPasswordMsg("Re-type your password");
      return false;
    } else if (newPassword !== retypeNewPassword) {
      setRetypeNewPasswordMsg("Re-typed password does not match with password");
      return false;
    } else {
      setRetypeNewPasswordMsg("");
    }

    if (newPassword && newPassword.length > 0) {
      setWaitBtn(true);
      let axiosHeader = {
        headers: {
          "Content-Type": "multipart/mixed",
        },
      };

      const data = new FormData();

      let apiURL = process.env.NEXT_PUBLIC_API_URL + "/newstudentregistration";
      let apiResponseTxt = "OK";
      if (utype && utype === "Teacher") {
        apiURL = process.env.NEXT_PUBLIC_API_URL + "/teacher-web-registration";
        apiResponseTxt = "success";
        data.append("teacherName", firstName + " " + lastName);
        data.append("mobile", mobileNumber);
        data.append("email", email);
        data.append("newPassword", newPassword);
      } else if (utype && utype === "Parent") {
        apiResponseTxt = "success";
        apiURL = process.env.NEXT_PUBLIC_API_URL + "/parent-web-registration";
        data.append("fullName", firstName + " " + lastName);
        data.append("mobile", mobileNumber);
        data.append("email", email);
        data.append("newPassword", newPassword);
      } else {
        Cookies.set(
          "accountDetails",
          JSON.stringify({
            studentName: firstName + " " + lastName,
            mobile: mobileNumber,
            email: email,
          })
        );
        window.location.href = "/create-account-process?user=new";
        return false;
      }

      axios
        .post(apiURL, data, axiosHeader)
        .then((response) => {
          const myTimeoutWaitBtn = setTimeout(myWaitBtnStop, 6000);
          function myWaitBtnStop() {
            setWaitBtn(false);
            clearTimeout(myTimeoutWaitBtn);
          }
          ///console.log("RESPONSE RECEIVED: ", response.data.responseTxt);
          if (response.data.responseTxt === apiResponseTxt) {
            if (utype && utype === "Teacher") {
              window.location.href =
                "/teacher/login?token=" + response.data.token;
            } else if (utype && utype === "Parent") {
              window.location.href =
                "/parent/login?token=" + response.data.obj.token;
            } else {
              // Cookies.set('accountDetails', JSON.stringify({studentId:response.data.studentId, studentName:firstName+' '+lastName, mobile:mobileNumber, email:email, token:response.data.token}));
              // Cookies.remove('newaccount');
              ///window.location.href='/create-account-process';
            }
            return false;
          } else {
            setRetypeNewPasswordMsg("Error somewhere, Try after sometime.");
            return false;
          }
        })
        .catch((error) => {
          setRetypeNewPasswordMsg("" + error);
          return false;
        });
    }
  }

  function onEnter(event) {
    if (event.key === "Enter") {
      submit();
    }
  }

  return (
    <>
      <Head>
        <title>Online Tests for Recruitment &amp; Entrance Exams</title>
        <meta
          name="description"
          content="Online Tests for Recruitment &amp; Entrance Exams"
        />
        <meta
          name="keywords"
          content="Online Tests for Recruitment &amp; Entrance Exams"
        />
        <link rel="icon" href="/favicon.ico" />
      </Head>

      <main>
        <Header />

        <Box className="mainBox">
          <Box className="createAccountBox">
            <Grid container>
              <Grid
                item
                md={6}
                sm={6}
                xs={12}
                className={classes.sectionDesktop}
              >
                <img src="/two.png" alt="ETL Image" />
              </Grid>
              <Grid item md={6} sm={6} xs={12}>
                <h1>Create your password</h1>
                <Grid className="frmbx">
                  <Grid container spacing={1}>
                    <Grid item md={12} sm={12} xs={12}>
                      New Password
                      <TextField
                        type="password"
                        onChange={(event) => setNewPassword(event.target.value)}
                        value={newPassword}
                        onKeyPress={(event) => {
                          onEnter(event);
                        }}
                        fullWidth
                        variant="outlined"
                      />
                      {newPasswordMsg && newPasswordMsg.length > 0 ? (
                        <FormHelperText>{newPasswordMsg}</FormHelperText>
                      ) : null}
                    </Grid>
                    <Grid item md={12} sm={12} xs={12}>
                      Re-type New Password
                      <TextField
                        type="password"
                        onChange={(event) =>
                          setRetypeNewPassword(event.target.value)
                        }
                        value={retypeNewPassword}
                        onKeyPress={(event) => {
                          onEnter(event);
                        }}
                        fullWidth
                        variant="outlined"
                      />
                      {retypeNewPasswordMsg &&
                      retypeNewPasswordMsg.length > 0 ? (
                        <FormHelperText>{retypeNewPasswordMsg}</FormHelperText>
                      ) : null}
                    </Grid>
                  </Grid>
                  <Grid container spacing={1}>
                    <Grid item md={12} sm={12} xs={12}>
                      <div className="paybtnbox">
                        {waitBtn ? (
                          <a className="paybtnwait">
                            <CircularProgress size={13} color={"inherit"} />
                            Wait...
                          </a>
                        ) : (
                          <a
                            href="javscript:;"
                            onClick={() => {
                              submit();
                            }}
                            className="paybtn"
                          >
                            CREATE MY PASSWORD
                          </a>
                        )}
                      </div>
                    </Grid>
                  </Grid>
                </Grid>
              </Grid>
            </Grid>
          </Box>
        </Box>
        <Footer />
      </main>
    </>
  );
}
