import React from "react";
import Head from "next/head";
import { makeStyles } from "@material-ui/core/styles";
import { Box, Grid, TextField } from "@material-ui/core";
import CircularProgress from "@mui/material/CircularProgress";
import Header from "../components/Header";
import Footer from "../components/Footer";
import FormHelperText from "@mui/material/FormHelperText";
import Cookies from "js-cookie";
import axios from "axios";

const useStyles = makeStyles((theme) => ({
  sectionDesktop: {
    display: "none",
    [theme.breakpoints.up("md")]: {
      display: "block",
    },
  },
  sectionMobile: {
    display: "block",
    [theme.breakpoints.up("md")]: {
      display: "none",
    },
  },
}));

export default function Home(props) {
  const newaccount = Cookies.get("newaccount");
  const classes = useStyles();
  const [waitBtn, setWaitBtn] = React.useState(false);

  const [utype, setUtype] = React.useState("Learner");
  const [firstName, setFirstName] = React.useState("");
  const [lastName, setLastName] = React.useState("");
  const [mobileNumber, setMobileNumber] = React.useState("");
  const [email, setEmail] = React.useState("");
  const [emailVal, setEmailVal] = React.useState(false);
  const [emailValMsg, setEmailValMsg] = React.useState("Enter your email");

  React.useEffect(() => {
    if (!newaccount) {
      window.location.href = "/create-account";
    } else if (newaccount) {
      const obj = JSON.parse(newaccount);
      setFirstName(obj.firstName);
      setLastName(obj.lastName);
      setMobileNumber(obj.mobile);
      setUtype(obj.utype);
      if (obj.email) {
        setEmail(obj.email);
      }
    }
  }, [newaccount]);

  const validateEmail = (email) => {
    return String(email)
      .toLowerCase()
      .match(
        /^(([^<>()[\]\\.,;:\s@"]+(\.[^<>()[\]\\.,;:\s@"]+)*)|(".+"))@((\[[0-9]{1,3}\.[0-9]{1,3}\.[0-9]{1,3}\.[0-9]{1,3}\])|(([a-zA-Z\-0-9]+\.)+[a-zA-Z]{2,}))$/
      );
  };

  function submit() {
    if (!email) {
      setEmailVal(true);
      return false;
    } else {
      setEmailVal(false);
    }

    if (email && email.length > 0 && !validateEmail(email)) {
      setEmailVal(true);
      setEmailValMsg("Email is not valid.");
      return false;
    }

    if (email) {
      setWaitBtn(true);
      let axiosHeader = {
        headers: {
          "Content-Type": "multipart/mixed",
        },
      };

      const data = new FormData();
      data.append("email", email);

      let apiURL = process.env.NEXT_PUBLIC_API_URL + "/checkexistsemailaddress";
      let apiResponseTxt = "OK";
      if (utype && utype === "Teacher") {
        apiURL = process.env.NEXT_PUBLIC_API_URL + "/teacher-checkexistsemail";
        apiResponseTxt = "success";
      } else if (utype && utype === "Parent") {
        apiResponseTxt = "success";
        apiURL = process.env.NEXT_PUBLIC_API_URL + "/parent-checkexistsemail";
      }

      axios
        .post(apiURL, data, axiosHeader)
        .then((response) => {
          const myTimeoutWaitBtn = setTimeout(myWaitBtnStop, 6000);
          function myWaitBtnStop() {
            setWaitBtn(false);
            clearTimeout(myTimeoutWaitBtn);
          }
          ///console.log("RESPONSE RECEIVED: ", response.data.responseTxt);
          if (response.data.responseTxt === apiResponseTxt) {
            Cookies.set(
              "newaccount",
              JSON.stringify({
                firstName: firstName,
                lastName: lastName,
                mobile: mobileNumber,
                email: email,
                token: response.data.token,
                utype: utype,
              })
            );
            window.location.href = "verify-email";
            return false;
          } else if (response.data.responseTxt === "EmailExists") {
            setEmailVal(true);
            setEmailValMsg("This Email address is already registered.");
            return false;
          } else {
            setEmailVal(true);
            setEmailValMsg("Error somewhere, Try after sometime.");
            return false;
          }
        })
        .catch((error) => {
          setEmailVal(true);
          setEmailValMsg("" + error);
          return false;
        });
    }
  }

  function onEnter(event) {
    if (event.key === "Enter") {
      submit();
    }
  }

  return (
    <>
      <Head>
        <title>Online Tests for Recruitment &amp; Entrance Exams</title>
        <meta
          name="description"
          content="Online Tests for Recruitment &amp; Entrance Exams"
        />
        <meta
          name="keywords"
          content="Online Tests for Recruitment &amp; Entrance Exams"
        />
        <link rel="icon" href="/favicon.ico" />
      </Head>

      <main>
        <Header />

        <Box className="mainBox">
          <Box className="createAccountBox">
            <Grid container>
              <Grid
                item
                md={6}
                sm={6}
                xs={12}
                className={classes.sectionDesktop}
              >
                <img
                  loading="lazy"
                  alt="ease to learn hero banner ETL"
                  src="/two.webp"
                />
              </Grid>
              <Grid item md={6} sm={6} xs={12}>
                <h1>Enter email</h1>
                <Grid className="frmbx">
                  <Grid container spacing={1} style={{ marginTop: 20 }}>
                    <Grid item md={12} sm={12} xs={12}>
                      Email Address
                      <TextField
                        onChange={(event) => setEmail(event.target.value)}
                        value={email}
                        onKeyPress={(event) => {
                          onEnter(event);
                        }}
                        fullWidth
                        variant="outlined"
                      />
                      {emailVal ? (
                        <FormHelperText>{emailValMsg}</FormHelperText>
                      ) : null}
                    </Grid>
                    <Grid item md={12} sm={12} xs={12}>
                      <div className="paybtnbox">
                        {waitBtn ? (
                          <a className="paybtnwait">
                            <CircularProgress size={13} color={"inherit"} />
                            Wait...
                          </a>
                        ) : (
                          <a
                            href="javscript:;"
                            onClick={() => {
                              submit();
                            }}
                            className="paybtn"
                          >
                            Submit
                          </a>
                        )}
                      </div>
                    </Grid>
                    <Grid item md={12} sm={12} xs={12}>
                      <div className="paybtnbox">
                        <a href="create-password">Skip</a>
                      </div>
                    </Grid>
                    <Grid item md={12} sm={12} xs={12}>
                      Note: <br />
                      We recommend you to enter your email address as a backup
                      if you ever get locked out of your account
                    </Grid>
                  </Grid>
                </Grid>
              </Grid>
            </Grid>
          </Box>
        </Box>

        <Footer />
      </main>
    </>
  );
}

/*
export async function getServerSideProps() {
	const [specialitiesRes, healthissuesRes, articlesRes] = await Promise.all([		
	  fetch(process.env.NEXT_PUBLIC_API_URL+'/api/specialities?maxrows=6'),
	  fetch(process.env.NEXT_PUBLIC_API_URL+'/api/healthissues?maxrows=6'), 
	  fetch(process.env.NEXT_PUBLIC_API_URL+'/api/articles?maxrows=3')	  
	]);
	const [specialities, healthissues, articles] = await Promise.all([
		specialitiesRes.json(),
		healthissuesRes.json(), 
		articlesRes.json()
	]);
	return { props: { specialities, healthissues, articles } };
}
*/

//   function makeEncodeURL(str){
// 	let strArr = str.toLowerCase().split(" ");
// 	let returnURL="";
// 	for(let i=0; i<strArr.length; i++ ){
// 		returnURL+=strArr[i]+"+";
// 	}
// 	 return returnURL.trim().substring(0,returnURL.length-1);
//   }
