import React, { useEffect, useState } from "react";
import { useRouter } from "next/router";
import Head from "next/head";
import { Box, Grid } from "@material-ui/core";
import Rating from "@mui/material/Rating";
import Avatar from "@mui/material/Avatar";

// Components
import Header from "../../components/Header";
import Footer from "../../components/Footer";
import Schema from "../../client/Schema";
import Favicon from "../../client/Favicon";
import Meta from "../../client/Meta";
import { homepageMeta } from "../../utils/Constants/metaConstants";
import { FontAwesomeIcon } from "@fortawesome/react-fontawesome";
import HomeSubjectCard from "../../components/Home/HomeSubjectCard/HomeSubjectCard";
import { faPlayCircle } from "@fortawesome/free-solid-svg-icons";
import HomeInnerBoxCard from "../../components/Home/HomeInnerBoxCard/HomeInnerBoxCard";

// CSS
import styles from "./studyRoom.module.css";

const index = (props) => {
  const router = useRouter();
  const canonicalUrl = (
    `https://easetolearn.com/` + (router.asPath === "/" ? "" : router.asPath)
  ).split("?")[0];

  // States
  const [severityAlert, setSeverityAlert] = useState("error");
  const [showAlert, setShowAlert] = useState(false);
  const [alertMessage, setAlertMessage] = useState("");
  const [playVideoOpt, setPlayVideoOpt] = useState(1);
  const [showHeader, setShowHeader] = useState(false);

  // Supporting Functions
  function playVideo(opt) {
    setPlayVideoOpt(opt);
    childRefHowItWorksPop.current.handleClickOpen();
  }

  function submit() {
    let emailTxtId = document.getElementById("emailTxtId");
    if (emailTxtId.value == "") {
      setSeverityAlert("error");
      setShowAlert(true);
      setAlertMessage("Enter your email");
      emailTxtId.focus();
      return false;
    }
    if (
      emailTxtId.value &&
      emailTxtId.value.length > 0 &&
      !validateEmail(emailTxtId.value)
    ) {
      setSeverityAlert("error");
      setShowAlert(true);
      setAlertMessage("Email is not valid");
      emailTxtId.focus();
      return false;
    }

    if (emailTxtId.value.length > 0) {
      let axiosHeader = {
        headers: {
          "Content-Type": "multipart/mixed",
        },
      };

      const data = new FormData();
      data.append("email", emailTxtId.value);

      axios
        .post(
          process.env.NEXT_PUBLIC_API_URL + "/website-emails",
          data,
          axiosHeader
        )
        .then((response) => {
          if (response.data.responseTxt === "success") {
            emailTxtId.value = "";
            setSeverityAlert("success");
            setShowAlert(true);
            setAlertMessage("Your message has been sent successfully.");
            return false;
          } else {
            // setFormMessage('Error somewhere, Try after sometime.');
            // return false;
          }
        })
        .catch((error) => {
          // setFormMessage(""+error);
          // return false;
        });
    }
  }

  const schema = {
    breadcrumbs: [
      {
        id: "https://www.easetolearn.com/",
        name: "Home",
      },
    ],
    faq: true,
    website: true,
    review: true,
    video: {
      name: "How does EaseToLearn Work?",
      url: "https://www.youtube.com/watch?v=3lhkCUPAFOY&t=8s",
      datePublished: "2023-05-04",
      uploadDate: "2023-05-04",
      thumbnailUrl: "https://media.easetolearn.com/CompanyLogo.png",
      description: "Fastest method of learning for exams",
    },
  };

  useEffect(() => {
    const handleScroll = (event) => {
      if (window.scrollY > 90) {
        setShowHeader(true);
      } else {
        setShowHeader(false);
      }
    };

    window.addEventListener("scroll", handleScroll);

    return () => {
      window.removeEventListener("scroll", handleScroll);
    };
  }, []);

  return (
    <>
      <Head>
        <title>Accelerating your exam preparation with AI- EaseToLearn</title>
        <Meta meta={homepageMeta} />
        <Favicon />
        <Schema schema={schema} />
      </Head>
      <main
        className={`${styles.study_room} ${
          showHeader ? "changeHeader" : `${styles.remove_background}`
        }`}
      >
        <Header />
        {/* Banner Section */}
        <section className={styles.study_room_banner}>
          <img
            src="/studyRoomCirlce.svg"
            className={styles.study_room_banner_circle}
            width={571}
            height={833}
            alt="studyRoom circle ETL"
          />
          <img
            src="/studyRoomCircle2.svg"
            className={styles.study_room_banner_circle}
            width={803}
            height={833}
            alt="studyRoom circle ETL"
          />
          <div>
            <img
              src="/rocket1.svg"
              className={styles.study_room_rocket}
              width={40}
              height={40}
            />
            <img
              src="/rocket1.svg"
              className={styles.study_room_rocket1}
              width={40}
              height={40}
              alt="ETL Rocket"
            />
            <img
              src="/rocket1.svg"
              className={styles.study_room_rocket2}
              width={40}
              height={40}
              alt="ETL Rocket"
            />
            <img
              src="/rocket1.svg"
              className={styles.study_room_rocket3}
              width={40}
              height={40}
              alt="ETL Rocket"
            />
            <img
              src="/rocket1.svg"
              className={styles.study_room_rocket4}
              width={40}
              height={40}
              alt="ETL Rocket"
            />
            <img
              src="/rocket1.svg"
              className={styles.study_room_rocket5}
              width={40}
              height={40}
              alt="ETL Rocket"
            />
            <img
              src="/rocket1.svg"
              className={styles.study_room_rocket6}
              width={40}
              height={40}
              alt="ETL Rocket"
            />
            <img
              src="/rocket1.svg"
              className={styles.study_room_rocket7}
              width={40}
              height={40}
              alt="ETL Rocket"
            />
            <img
              src="/rocket1.svg"
              className={styles.study_room_rocket8}
              width={40}
              height={40}
              alt="ETL Rocket"
            />
            <img
              src="/rocket1.svg"
              className={styles.study_room_rocket9}
              width={40}
              height={40}
              alt="ETL Rocket"
            />
            <img
              src="/rocket1.svg"
              className={styles.study_room_rocket10}
              width={40}
              height={40}
              alt="ETL Rocket"
            />
            <img
              src="/rocket1.svg"
              className={styles.study_room_rocket11}
              width={40}
              height={40}
              alt="ETL Rocket"
            />
          </div>
          <div
            className={`${styles.flex_display} ${styles.study_room_banner_container}`}
          >
            <div
              className={`${styles.flex_display} ${styles.study_room_banner_content}`}
            >
              {/* <p className={styles.study_room_span}>MY STUDY ROOM</p> */}
              {/* <h1>
                GET ACCESS TO
                <span className={styles.study_room_heading_span}>
                  <span className={styles.study_room_limitless}>LIMITLESS</span>{" "}
                  <span className={styles.study_room_learning}>LEARNING</span>
                </span>
              </h1> */}
              <h1>Let's revolutionise the way you learn with AI!</h1>
              <h2>Accelerating your exam preparation with EaseToLearn!</h2>
              <p>
                We are transforming the way students learn, teachers teach, and
                parents support their children's education.
              </p>
              <span>Discover the EaseToLearn difference now!</span>
              <a href="/create-account">Join Now</a>
            </div>
            <div
              className={`${styles.flex_display} ${styles.study_room_banner_image}`}
            >
              <img
                src="/rocketman.svg"
                width={642}
                height={504}
                alt="ETL Rocket man"
              />
            </div>
          </div>
        </section>
        <img
          src="/bottom1.svg"
          className={styles.study_room_banner_bottom}
          alt="ETL Image"
        />

        {/* Main Content */}
        <section className={styles.mainContent}>
          <h2 className={styles.revolution_heading}>
            The AI revolution is here!
          </h2>
          <p className={styles.revolution_para}>
            We as humans harbor a multitude of capacities. Being forced to learn
            linearly is only an inhibition of our talents. We, at EaseToLearn
            aim to create an infrastructure of learning that will enable
            intensive comprehension without it being a burden. Through our
            services, we strive toward reshaping the entire learning culture by
            - <b>Empowering Learners</b>, <b>Engaging Parents</b> and{" "}
            <b>Facilitating Educators</b>.
          </p>
          <div className={styles.revolution_cards}>
            <div className={styles.revolution_card}>
              <img src="/card1.svg" alt="ETL-svg" />
              <h3>Empowering Learners.</h3>
              <p>ETL Student App - Revolutionize the way you learn</p>
              <ul>
                <li>
                  <b>Smart Learning</b>: Identify and bridge knowledge gaps
                  rapidly.
                </li>
                <li>
                  <b>Smart Learning</b>: Aggregate resources for seamless
                  learning.
                </li>
                <li>
                  <b>Topic Test Simulator</b>: Realistic topic-specific
                  assessments.
                </li>
                <li>
                  <b>Exam Simulator</b>: Mimic real exam conditions for precise
                  evaluation.
                </li>
                <li>
                  <b>Performance Analytics</b>: Track progress and enhance
                  exam readiness
                </li>
              </ul>
            </div>
            <div className={styles.revolution_card}>
              <img src="/card3.svg" alt="ETL-svg" />
              <h3>Facilitating Educators.</h3>
              <p>
                ETL Teacher App - tool to engage students and manage classes
              </p>
              <ul>
                <li>
                  <b>AI-based Assessments</b>: Instant feedback for class and
                  students.
                </li>
                <li>
                  <b>Mock Tests</b>: Subject and exam-specific simulations.
                </li>
                <li>
                  <b>Content Sharing</b>: Seamless sharing of educational
                  materials.
                </li>
                <li>
                  <b>Insights</b>: Get insights to enhance
                  teaching effectiveness.
                </li>
                <li>
                  <b>Doubt Clearing</b>: Remote or online, individually or in
                  batches.
                </li>
              </ul>
            </div>
            <div className={styles.revolution_card}>
              <img src="/card2.svg" alt="ETL-svg" />
              <h3>Engaging Parents.</h3>
              <p>ETL Parent App - Monitor and track your child's progress</p>
              <ul>
                <li>
                  <b>Engage</b>: to support your child’s educational journey
                  with real time updates
                </li>
                <li>
                  <b>Dashboard</b>: Snap shot view of performance at your
                  fingertips
                </li>
                <li>
                  <b>Reports and Analytics</b>: Drill down graphs, charts, and
                  analytics to understand shortcomings in detail
                </li>
                <li>
                  <b>Communication</b>: with teachers/mentors and SME
                </li>
              </ul>
            </div>
          </div>
        </section>

        {/* Signup */}
        <section className={styles.get_signups}>
          <div className={styles.get_signups_content}>
            <h3>Crack your next exam with EaseToLearn</h3>
            <p>
              Get unlimited access to structured courses, doubt clearing
              sessions & mock exams
            </p>
            <a href="/create-account">Start preparing for free</a>
          </div>
          <div className={styles.get_signups_cards}>
            <div>
              <div className={styles.get_signups_card}>
                <p>
                  130<span>+</span>
                </p>
                <span>Exam courses</span>
              </div>
              <div className={styles.get_signups_card}>
                <p>
                  5K<span>+</span>
                </p>
                <span>Study materials</span>
              </div>
            </div>
            <div>
              <div className={styles.get_signups_card}>
                <p>
                  500K<span>+</span>
                </p>
                <span>Questions</span>
              </div>
              <div className={styles.get_signups_card}>
                <p>
                  1M<span>+</span>
                </p>
                <span>Assessments taken</span>
              </div>
              <div className={styles.get_signups_card}>
                <p>Infinite</p>
                <span>AI generated assessments</span>
              </div>
            </div>
          </div>
        </section>

        <section className="bg-box gradient margin-bottombox">
          <div className="barbox-head">
            <h3 className="fixhead">So, what is MY Study Room™ ?</h3>
            <div className="bar"></div>
          </div>
          <div className="bg-padding-flex ">
            <div className="slider-cont">
              <h4 className="heading">
                Introducing a game changer in the way you Learn
              </h4>
              <p>
                Bid farewell to running off to a thousand different places, we
                have it all under one roof! Study room enables comprehensive
                self-learning. You waste more time in searching material than
                studying it. The study room solves this problem by providing
                carefully curated study material and a self-assessment tool
                which helps you accelerate your learning by identifying the gaps
                in your knowledge and assisting you to fill the knowledge gaps
                then and there. It is assessment for learning. You focus only on
                the subject areas not known to you thus saving your precious
                time. It makes learning stress free but is still challenging and
                enjoyable. You achieve well-rounded knowledge of all the
                concepts. Unlike your other study buddies, the study room
                doesn’t hesitate to share its study material and self-
                assessor/learner completely free to cost.
              </p>
            </div>

            <div className={styles.sliderimg}>
              <img
                loading="lazy"
                alt="study room helper image ETL"
                src="/whatstudyroom.webp"
                width="408"
                height="357"
              />
            </div>
          </div>
          <br />
          <br /> <br />
          <br />
          <div className="mycontainer">
            <h3 className="heading">
              What Benefits do you get if you opt MY Study Room™ ?
            </h3>

            <HomeInnerBoxCard />
          </div>
        </section>

        <section className="mycontainer margin-bottommin">
          <div className="barbox-head color-dark">
            <h3 className="fixhead">What do we get with MY Study Room™ ?</h3>
            <div className="bar bg-dark"></div>
          </div>

          <div className="grid-two-bg gap15 ">
            <div className="inner-bg-box border20">
              <img
                loading="lazy"
                alt="girl with headphones on a laptop ETL"
                src="/headphone-girl.webp"
                width="100%"
              />

              <div className="cont-bg">
                <div className="bottomtext">
                  <h4>Study Material</h4>
                  <p>
                    Study Materials in form of Videos, PPTs, PDFs, HTML pages
                    organized in hierarchical manner
                    subject-wise/topic-wise/subtopic-wise and keyword-wise.
                  </p>
                </div>
              </div>
            </div>

            <div className="inner-bg-box border20">
              <img
                loading="lazy"
                alt="analytics on a laptop ETL"
                src="/anlatics.webp"
                width="100%"
              />

              <div className="cont-bg">
                <div className="bottomtext">
                  <h4>Smart Learning</h4>
                  <p>
                    Smart Learning to simulate your own assessments
                    subject-wise/topic-wise/subtopic-wise and keyword-wise to
                    identify gaps in your knowledge
                  </p>
                </div>
              </div>
            </div>
          </div>

          <img
            loading="lazy"
            alt="handshake icon ETL"
            src="/hand.webp"
            width={250}
            height={121}
            className="handicon"
          />
        </section>

        <section className="mycontainer ">
          <h3 className="heading color-dark">
            Subject we Offer FREE of cost with MY Study Room™ ?
          </h3>
          {/* Cards for home page subjects */}
          <HomeSubjectCard />
        </section>

        <section className="bg-box gradient margin-bottombox bg-dark-plus">
          <div className="barbox-head yellow">
            <h4 className="fixhead">Behold... MY Exam Room™ </h4>
            <div className="bar"></div>
          </div>

          <div className="bg-padding-flex ">
            <div className="slider-cont">
              <p>
                MY Exam Room helps comprehensive preparation of all competitive
                exams and recruitment exams. The topic and exam (mock) tests are
                simulated on extensive predefined parameters such as Types of
                questions, Number of questions, Level of Questions, Difficulty
                of questions, Marks methodology, Time to complete the test,
                Topics/subtopics weightage using historical patterns, Questions
                number and type topic/subtopic wise using patterns and
                intelligence, Section-wise definitions if required and
                Benchmarks based of historical results and subjects matter
                expert. This all along with inputs covering exam guidelines and
                previous year trends using computer intelligence and creating
                patterns near to examiner's mind. As such the accuracy of test
                is good and results give accurate indication of success or
                failures in upcoming exams.
              </p>
            </div>

            <div className={styles.sliderimg}>
              <img
                loading="lazy"
                alt="girl with pencil and board illustration ETL"
                src="/theexamprep.webp"
                width={408}
                height={342}
              />
            </div>
          </div>

          <div className="min-bottommin-res"></div>

          <div className="mycontainer marginb150">
            <h4 className="heading text-center">
              How is MY Exam Room™ Different From Study Room™
            </h4>

            <div className="grid-two border20 w80 withbar min-height">
              <div className="innercard study">
                <h5 className="color-dark">
                  MY Study Room™
                  <FontAwesomeIcon
                    icon={faPlayCircle}
                    style={{
                      color: "#FF0000",
                      cursor: "pointer",
                      height: 30,
                    }}
                    title="Click to play video"
                    onClick={() => {
                      playVideo(2);
                    }}
                  />
                </h5>
                <img
                  loading="lazy"
                  alt="girl studying many subjects ETL"
                  src="/studyroom.webp"
                  width={261}
                  height={237}
                />
                <h5>Assessment for Learning- FREE of cost for lifetime. </h5>

                <p>
                  Study Room is based on concept of Formative Assessments
                  wherein assessments are used to enhance and speed up learning
                  aided by our Study Material, books, teachers and web. Learners
                  have complete freedom to take help and fill gaps in their
                  knowledge. Formative Assessments are more central to
                  individual learning and as such learners are not graded. Even
                  marks are yardsticks to measure individual performance and not
                  for comparison/grading, It is Assessment FOR Learning.
                </p>
              </div>

              <div className="innercard study">
                <h5 className="color-dark">
                  MY Exam Room™
                  <FontAwesomeIcon
                    icon={faPlayCircle}
                    style={{
                      color: "#FF0000",
                      cursor: "pointer",
                      height: 30,
                    }}
                    title="Click to play video"
                    onClick={() => {
                      playVideo(3);
                    }}
                  />
                </h5>

                <img
                  loading="lazy"
                  alt="girl preparing for an exam ETL"
                  src="/examprep.webp"
                  width={261}
                  height={237}
                />

                <h5>Assessment of Learning with professional test series</h5>

                <p>
                  MY Exam Room is based on concept of Summative Assessment.
                  These assessments are typically done after student has
                  completed the study of topics/subjects. These are used to
                  evaluate or grade the students at the end of academic period
                  or at pre-determined time. In competitive exams, the results
                  of summative assessments are used to select the students for a
                  course or job. The tests are in a controlled environment with
                  marking patterns and are to be completed in stipulated time.
                  This is Assessment OF Learning.
                </p>
              </div>
            </div>
          </div>
        </section>

        

        {/* Course Section */}
        <section className={styles.courses}>
          <h2>Popular Exams</h2>
          <div className={styles.courses_cards}>
            <a href="/course/jee-main" className={styles.courses_card}>
              <div className={styles?.course_card_img}>
                <img
                  loading="lazy"
                  alt="course icon ETL"
                  src="/corsicon.webp"
                  style={{maxWidth: 80}}
                />
              </div>
              <p>Jee Mains</p>
            </a>
            <a href="/course/jee-advanced" className={styles.courses_card}>
              <div className={styles?.course_card_img}>
                <img
                  loading="lazy"
                  alt="course icon ETL"
                  src="/corsicon.webp"
                  style={{maxWidth: 80}}

                />
              </div>
              <p>JEE Advanced</p>
            </a>
            <a href="/course/neet-ug" className={styles.courses_card}>
              <div className={styles?.course_card_img}>
                <img
                  loading="lazy"
                  alt="course icon ETL"
                  src="/corsicon.webp"
                  style={{maxWidth: 80}}

                />
              </div>
              <p>NEET UG</p>
            </a>
            <a href="/course/neet-pg" className={styles.courses_card}>
              <div className={styles?.course_card_img}>
                <img
                  loading="lazy"
                  alt="course icon ETL"
                  src="/corsicon.webp"
                  style={{maxWidth: 80}}

                />
              </div>
              <p>NEET PG</p>
            </a>
            <a href="/course/sbi-po" className={styles.courses_card}>
              <div className={styles?.course_card_img}>
                <img
                  loading="lazy"
                  alt="course icon ETL"
                  src="/corsicon.webp"
                  style={{maxWidth: 80}}

                />
              </div>
              <p>SBI-PO</p>
            </a>
            <a
              href="/course/upsc-civil-services-exam"
              className={styles.courses_card}
            >
              <div className={styles?.course_card_img}>
                <img
                  loading="lazy"
                  alt="course icon ETL"
                  src="/corsicon.webp"
                  style={{maxWidth: 80}}

                />
              </div>
              <p>UPSC-CIVIL-SERVICES-EXAM</p>
            </a>
            <a href="/course/nda" className={styles.courses_card}>
              <div className={styles?.course_card_img}>
                <img
                  loading="lazy"
                  alt="course icon ETL"
                  src="/corsicon.webp"
                  style={{maxWidth: 80}}

                />
              </div>
              <p>NDA</p>
            </a>
            <a href="/course/bitsat" className={styles.courses_card}>
              <div className={styles?.course_card_img}>
                <img
                  loading="lazy"
                  alt="course icon ETL"
                  src="/corsicon.webp"
                  style={{maxWidth: 80}}

                />
              </div>
              <p>BITSAT</p>
            </a>
          </div>
        </section>

        {/* Comments Section */}
        <section className="mycontainer" style={{ marginTop: 60 }}>
          <div className="barbox-head color-dark">
            <h2 className={styles.content_heading}>Customer Testimonials</h2>
            <div className="bar bg-dark"></div>
          </div>
        </section>

        <section className="mycontainer relative" style={{ marginTop: 60 }}>
          <div
            style={{
              display: "flex",
              flexWrap: "wrap",
              gap: "2rem",
              justifyContent: "center",
            }}
          >
            {props.data && props.data.list && props.data.list.length > 0
              ? props.data.list.map((row, i) => (
                  <Box
                    key={"t" + i}
                    sx={{
                      display: "inline",
                      flexDirection: "column",
                      bgcolor: "white",
                      p: "1.5rem",
                      borderRadius: "1rem",
                      width: "340px",
                    }}
                  >
                    <div className="testimonailbox">
                      <div className="topbox">
                        <div
                          style={{
                            justifyContent: "center",
                            display: "flex",
                          }}
                        >
                          <Avatar
                            alt={row.studentName}
                            src={row.profilePic}
                            sx={{ width: 56, height: 56 }}
                          />
                        </div>
                        <div className="authorname">
                          <h4>{row.studentName}</h4>
                          <Rating
                            defaultValue={row.rating}
                            precision={0.5}
                            readOnly={true}
                          />
                        </div>
                      </div>
                      <div className="testi-cont">
                        <p>{row.remarks}</p>
                      </div>
                    </div>
                  </Box>
                ))
              : null}
          </div>
        </section>

        <section className={styles.mobile_container}>
          <Box
            alignItems="center"
            justifyContent="center"
            margin="5vh 12% 5vh 12%"
            className="mobileAppBox"
          >
            <Grid container>
              <Grid item md={6} sm={6} xs={12}>
                <h4 className="color-dark">
                  Do more with the
                  <br />
                  EaseToLearn Mobile App
                </h4>
                <p>
                  Download lessons and learn anytime, anywhere. All within the
                  grasp of your fingertips!
                </p>
                <p className="btnbox">
                  <a
                    href="https://play.google.com/store/apps/details?id=com.easetolearn.indiaexampreparation"
                    target="_blank"
                  >
                    <img
                      loading="lazy"
                      alt="Google Play icon ETL"
                      src="/google-play.webp"
                      width={165}
                      height={50}
                    />
                  </a>
                </p>
              </Grid>
              <Grid item md={6} sm={6} xs={12}>
                <div className="imgbox">
                  <a
                    href="https://play.google.com/store/apps/details?id=com.easetolearn.indiaexampreparation"
                    target="_blank"
                  >
                    <img
                      loading="lazy"
                      alt="easetolearn mobile app mockup ETL"
                      src="/mobileapp.webp"
                      width={175}
                      height={250}
                    />
                  </a>
                </div>
              </Grid>
            </Grid>
          </Box>
        </section>

        {/* Blog */}
        <section className={styles.blogs}>
          <h2>Our Blogs</h2>
          <div className={styles.blogs_cards}>
            <div className={styles.blogs_card}>
              <div className={styles?.course_card_img}>
                <img
                  loading="lazy"
                  alt="course icon ETL"
                  src="https://easetolearn.com/info/wp-content/uploads/2023/04/Untitled-design-11.jpg"
                />
              </div>
              <p>Indian education system is not conducive for learning</p>
              <div className={styles.blog_button}>
                <a href="https://easetolearn.com/info/index.php/2022/12/28/indian-education-system-is-not-conducive-for-learning/">
                  Read More
                </a>
              </div>
            </div>
            <div className={styles.blogs_card}>
              <div className={styles?.course_card_img}>
                <img
                  loading="lazy"
                  alt="course icon ETL"
                  src="https://easetolearn.com/info/wp-content/uploads/2023/04/Untitled-design-12.jpg"
                />
              </div>
              <p>Studies after school hours-EaseToLearn</p>
              <div className={styles.blog_button}>
                <a href="https://easetolearn.com/info/index.php/2023/01/03/studies-after-school-hours-easetolearn/">
                  Read More
                </a>
              </div>
            </div>
            <div className={styles.blogs_card}>
              <div className={styles?.course_card_img}>
                <img
                  loading="lazy"
                  alt="course icon ETL"
                  src="https://easetolearn.com/info/wp-content/uploads/2023/04/Untitled-design-13.jpg"
                />
              </div>
              <p>Life cycle of a student.</p>
              <div className={styles.blog_button}>
                <a href="https://easetolearn.com/info/index.php/2023/01/04/life-cycle-of-a-student/">
                  Read More
                </a>
              </div>
            </div>
          </div>
        </section>

        {/* Email */}
        <section className={styles.email_container}>
          <section className="mycontainer" style={{ marginTop: 60 }}>
            <div className="subscribebox">
              <h4 className="color-dark">
                Subscribe to our email
                <br />
                for latest news and updates
              </h4>
              <form className="submitbox">
                <input
                  type="email"
                  id="emailTxtId"
                  placeholder="Enter your email address"
                />
                <button
                  type="button"
                  onClick={() => {
                    submit();
                  }}
                  className="btn"
                >
                  Submit
                </button>
              </form>
            </div>

            <div className="bottommin-res"></div>
          </section>
        </section>
        <Footer />
      </main>
    </>
  );
};

export async function getServerSideProps() {
  const res = await fetch(process.env.NEXT_PUBLIC_API_URL + "/website-ratings");
  const response = await fetch(
    process.env.NEXT_PUBLIC_API_URL +
      "/website-categoryandcourses?webUrl=" +
      process.env.NEXT_PUBLIC_WEB_URL_FOR_COURSES
  );
  const data = await res.json();
  const search = await response?.json();
  return { props: { data, response: search } };
}

export default index;
